pub struct PositionStateSnapshot {
pub position: Position,
pub unrealized_pnl: Option<Money>,
pub ts_snapshot: UnixNanos,
}Expand description
Position state snapshot published to the snapshots.position.{position_id} topic.
Fields
position: PositionThe position state at the time of the snapshot.
unrealized_pnl: Option<Money>The unrealized PnL for the position, when a current quote is available.
ts_snapshot: UnixNanosUNIX timestamp (nanoseconds) when the snapshot was taken.